==> aws-cdk-lib-2.0.0-rc.14-sources.jar: software/amazon/awscdk/cloudassembly/schema/MissingContext.java <==
package software.amazon.awscdk.cloudassembly.schema;

/**
 * (experimental) Represents a missing piece of context.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.31.0 (build 6fa403d)", date = "2021-07-21T10:24:58.883Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.cloud_assembly_schema.MissingContext")
@software.amazon.jsii.Jsii.Proxy(MissingContext.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface MissingContext extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) The missing context key.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull java.lang.String getKey();

    /**
     * (experimental) A set of provider-specific options.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull java.lang.Object getProps();

    /**
     * (experimental) The provider from which we expect this context key to be obtained.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.cloudassembly.schema.ContextProvider getProvider();

    /**
     * @return a {@link Builder} of {@link MissingContext}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link MissingContext}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<MissingContext> {
        private java.lang.String key;
        private java.lang.Object props;
        private software.amazon.awscdk.cloudassembly.schema.ContextProvider provider;

        /**
         * Sets the value of {@link MissingContext#getKey}
         * @param key The missing context key. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder key(java.lang.String key) {
            this.key = key;
            return this;
        }

        /**
         * Sets the value of {@link MissingContext#getProps}
         * @param props A set of provider-specific options. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder props(software.amazon.awscdk.cloudassembly.schema.AmiContextQuery props) {
            this.props = props;
            return this;
        }

        /**
         * Sets the value of {@link MissingContext#getProps}
         * @param props A set of provider-specific options. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder props(software.amazon.awscdk.cloudassembly.schema.AvailabilityZonesContextQuery props) {
            this.props = props;
            return this;
        }

        /**
         * Sets the value of {@link MissingContext#getProps}
         * @param props A set of provider-specific options. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder props(software.amazon.awscdk.cloudassembly.schema.HostedZoneContextQuery props) {
            this.props = props;
            return this;
        }

        /**
         * Sets the value of {@link MissingContext#getProps}
         * @param props A set of provider-specific options. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder props(software.amazon.awscdk.cloudassembly.schema.SSMParameterContextQuery props) {
            this.props = props;
            return this;
        }

        /**
         * Sets the value of {@link MissingContext#getProps}
         * @param props A set of provider-specific options. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder props(software.amazon.awscdk.cloudassembly.schema.VpcContextQuery props) {
            this.props = props;
            return this;
        }

        /**
         * Sets the value of {@link MissingContext#getProps}
         * @param props A set of provider-specific options. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder props(software.amazon.awscdk.cloudassembly.schema.EndpointServiceAvailabilityZonesContextQuery props) {
            this.props = props;
            return this;
        }

        /**
         * Sets the value of {@link MissingContext#getProps}
         * @param props A set of provider-specific options. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder props(software.amazon.awscdk.cloudassembly.schema.LoadBalancerContextQuery props) {
            this.props = props;
            return this;
        }

        /**
         * Sets the value of {@link MissingContext#getProps}
         * @param props A set of provider-specific options. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder props(software.amazon.awscdk.cloudassembly.schema.LoadBalancerListenerContextQuery props) {
            this.props = props;
            return this;
        }

        /**
         * Sets the value of {@link MissingContext#getProps}
         * @param props A set of provider-specific options. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder props(software.amazon.awscdk.cloudassembly.schema.SecurityGroupContextQuery props) {
            this.props = props;
            return this;
        }

        /**
         * Sets the value of {@link MissingContext#getProvider}
         * @param provider The provider from which we expect this context key to be obtained. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder provider(software.amazon.awscdk.cloudassembly.schema.ContextProvider provider) {
            this.provider = provider;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link MissingContext}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public MissingContext build() {
            return new Jsii$Proxy(key, props, provider);
        }
    }

    /**
     * An implementation for {@link MissingContext}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements MissingContext {
        private final java.lang.String key;
        private final java.lang.Object props;
        private final software.amazon.awscdk.cloudassembly.schema.ContextProvider provider;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.key = software.amazon.jsii.Kernel.get(this, "key", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.props = software.amazon.jsii.Kernel.get(this, "props", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
            this.provider = software.amazon.jsii.Kernel.get(this, "provider", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.cloudassembly.schema.ContextProvider.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final java.lang.String key, final java.lang.Object props, final software.amazon.awscdk.cloudassembly.schema.ContextProvider provider) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.key = java.util.Objects.requireNonNull(key, "key is required");
            this.props = java.util.Objects.requireNonNull(props, "props is required");
            this.provider = java.util.Objects.requireNonNull(provider, "provider is required");
        }

        @Override
        public final java.lang.String getKey() {
            return this.key;
        }

        @Override
        public final java.lang.Object getProps() {
            return this.props;
        }

        @Override
        public final software.amazon.awscdk.cloudassembly.schema.ContextProvider getProvider() {
            return this.provider;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("key", om.valueToTree(this.getKey()));
            data.set("props", om.valueToTree(this.getProps()));
            data.set("provider", om.valueToTree(this.getProvider()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.cloud_assembly_schema.MissingContext"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            MissingContext.Jsii$Proxy that = (MissingContext.Jsii$Proxy) o;

            if (!key.equals(that.key)) return false;
            if (!props.equals(that.props)) return false;
            return this.provider.equals(that.provider);
        }

        @Override
        public final int hashCode() {
            int result = this.key.hashCode();
            result = 31 * result + (this.props.hashCode());
            result = 31 * result + (this.provider.hashCode());
            return result;
        }
    }
}

==> aws-cdk-lib-2.10.0-sources.jar: software/amazon/awscdk/cloudassembly/schema/MissingContext.java <==
package software.amazon.awscdk.cloudassembly.schema;

/**
 * Represents a missing piece of context.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.cloudassembly.schema.*;
 * MissingContext missingContext = MissingContext.builder()
 *         .key("key")
 *         .props(AmiContextQuery.builder()
 *                 .account("account")
 *                 .filters(Map.of(
 *                         "filtersKey", List.of("filters")))
 *                 .region("region")
 *                 // the properties below are optional
 *                 .lookupRoleArn("lookupRoleArn")
 *                 .owners(List.of("owners"))
 *                 .build())
 *         .provider(ContextProvider.AMI_PROVIDER)
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.52.1 (build 5ccc8f6)", date = "2022-01-29T04:34:13.542Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.cloud_assembly_schema.MissingContext")
@software.amazon.jsii.Jsii.Proxy(MissingContext.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface MissingContext extends software.amazon.jsii.JsiiSerializable {

    /**
     * The missing context key.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getKey();

    /**
     * A set of provider-specific options.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.Object getProps();

    /**
     * The provider from which we expect this context key to be obtained.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.cloudassembly.schema.ContextProvider getProvider();

    /**
     * @return a {@link Builder} of {@link MissingContext}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link MissingContext}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<MissingContext> {
        java.lang.String key;
        java.lang.Object props;
        software.amazon.awscdk.cloudassembly.schema.ContextProvider provider;

        /**
         * Sets the value of {@link MissingContext#getKey}
         * @param key The missing context key. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder key(java.lang.String key) {
            this.key = key;
            return this;
        }

        /**
         * Sets the value of {@link MissingContext#getProps}
         * @param props A set of provider-specific options. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder props(software.amazon.awscdk.cloudassembly.schema.AmiContextQuery props) {
            this.props = props;
            return this;
        }

        /**
         * Sets the value of {@link MissingContext#getProps}
         * @param props A set of provider-specific options. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder props(software.amazon.awscdk.cloudassembly.schema.AvailabilityZonesContextQuery props) {
            this.props = props;
            return this;
        }

        /**
         * Sets the value of {@link MissingContext#getProps}
         * @param props A set of provider-specific options. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder props(software.amazon.awscdk.cloudassembly.schema.HostedZoneContextQuery props) {
            this.props = props;
            return this;
        }

        /**
         * Sets the value of {@link MissingContext#getProps}
         * @param props A set of provider-specific options. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder props(software.amazon.awscdk.cloudassembly.schema.SSMParameterContextQuery props) {
            this.props = props;
            return this;
        }

        /**
         * Sets the value of {@link MissingContext#getProps}
         * @param props A set of provider-specific options. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder props(software.amazon.awscdk.cloudassembly.schema.VpcContextQuery props) {
            this.props = props;
            return this;
        }

        /**
         * Sets the value of {@link MissingContext#getProps}
         * @param props A set of provider-specific options. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder props(software.amazon.awscdk.cloudassembly.schema.EndpointServiceAvailabilityZonesContextQuery props) {
            this.props = props;
            return this;
        }

        /**
         * Sets the value of {@link MissingContext#getProps}
         * @param props A set of provider-specific options. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder props(software.amazon.awscdk.cloudassembly.schema.LoadBalancerContextQuery props) {
            this.props = props;
            return this;
        }

        /**
         * Sets the value of {@link MissingContext#getProps}
         * @param props A set of provider-specific options. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder props(software.amazon.awscdk.cloudassembly.schema.LoadBalancerListenerContextQuery props) {
            this.props = props;
            return this;
        }

        /**
         * Sets the value of {@link MissingContext#getProps}
         * @param props A set of provider-specific options. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder props(software.amazon.awscdk.cloudassembly.schema.SecurityGroupContextQuery props) {
            this.props = props;
            return this;
        }

        /**
         * Sets the value of {@link MissingContext#getProps}
         * @param props A set of provider-specific options. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder props(software.amazon.awscdk.cloudassembly.schema.KeyContextQuery props) {
            this.props = props;
            return this;
        }

        /**
         * Sets the value of {@link MissingContext#getProvider}
         * @param provider The provider from which we expect this context key to be obtained. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder provider(software.amazon.awscdk.cloudassembly.schema.ContextProvider provider) {
            this.provider = provider;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link MissingContext}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public MissingContext build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link MissingContext}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements MissingContext {
        private final java.lang.String key;
        private final java.lang.Object props;
        private final software.amazon.awscdk.cloudassembly.schema.ContextProvider provider;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.key = software.amazon.jsii.Kernel.get(this, "key", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.props = software.amazon.jsii.Kernel.get(this, "props", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
            this.provider = software.amazon.jsii.Kernel.get(this, "provider", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.cloudassembly.schema.ContextProvider.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.key = java.util.Objects.requireNonNull(builder.key, "key is required");
            this.props = java.util.Objects.requireNonNull(builder.props, "props is required");
            this.provider = java.util.Objects.requireNonNull(builder.provider, "provider is required");
        }

        @Override
        public final java.lang.String getKey() {
            return this.key;
        }

        @Override
        public final java.lang.Object getProps() {
            return this.props;
        }

        @Override
        public final software.amazon.awscdk.cloudassembly.schema.ContextProvider getProvider() {
            return this.provider;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("key", om.valueToTree(this.getKey()));
            data.set("props", om.valueToTree(this.getProps()));
            data.set("provider", om.valueToTree(this.getProvider()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.cloud_assembly_schema.MissingContext"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            MissingContext.Jsii$Proxy that = (MissingContext.Jsii$Proxy) o;

            if (!key.equals(that.key)) return false;
            if (!props.equals(that.props)) return false;
            return this.provider.equals(that.provider);
        }

        @Override
        public final int hashCode() {
            int result = this.key.hashCode();
            result = 31 * result + (this.props.hashCode());
            result = 31 * result + (this.provider.hashCode());
            return result;
        }
    }
}
